@@ -65,7 +65,8 @@ static GString *message_to_display;
 
 static gboolean vfs_scan_nok;
 
-gint spawn_proc (gchar * path, gint narg, gchar ** arg)
+gint
+spawn_proc (gchar * path, gint narg, gchar ** arg)
 {
   gchar **arg2;
   int i, pid;
@@ -95,7 +96,8 @@ gint spawn_proc (gchar * path, gint narg, gchar ** arg)
     }
 }
 
-guint du_s (gchar * path)
+guint
+du_s (gchar * path)
 {
   int p[2];
   static gchar buffer[1024];
@@ -169,8 +171,7 @@ set_message_to_display (GString * message)
   is_message_to_display = TRUE;
 }
 
-gboolean
-eject_disk (CONFIG * my_config)
+gboolean eject_disk (CONFIG * my_config)
 {
   int status, pid;
   char *args[2];
@@ -202,8 +203,7 @@ eject_disk (CONFIG * my_config)
   return (TRUE);
 }
 
-gboolean
-mount_disk (CONFIG * my_config)
+gboolean mount_disk (CONFIG * my_config)
 {
 #if defined(OS_LINUX)
   int pid, status;
@@ -213,7 +213,7 @@ mount_disk (CONFIG * my_config)
   seteuid (getuid ());
   args[0] = my_config->mount->str;
   args[1] = escapespaces (my_config->mount_point->str);
-  printf("%s %s\n", args[0], args[1]);
+
   while (tries >= 0)
     {
       pid = spawn_proc (NULL, 2, args);
@@ -240,7 +240,7 @@ mount_disk (CONFIG * my_config)
       if (tries >= 0)
 	sleep (MOUNT_RETRY_TIMEOUT);
     }
-  
+
   set_message_to_display (g_string_new (_("Mount failed! Disk in use?")));
   return (FALSE);
 #elif defined(OS_FREEBSD) || defined(OS_NETBSD)
@@ -260,8 +260,7 @@ mount_disk (CONFIG * my_config)
 #endif
 }
 
-gboolean
-umount_disk (CONFIG * my_config)
+gboolean umount_disk (CONFIG * my_config)
 {
 #if defined(OS_LINUX)
   int pid, status;
@@ -346,8 +345,7 @@ init_vfs_scan_status (void)
   vfs_scan_nok = FALSE;
 }
 
-gint
-my_timeout (gpointer data)
+gint my_timeout (gpointer data)
 {
   FOLDER *racine = data;
 /*  FILE_DATA *fd;*/
@@ -515,8 +513,7 @@ read_information (gchar * file, gchar * mime)
   return (information_string);
 }
 
-gboolean
-is_dir_openable (char *dir_name)
+gboolean is_dir_openable (char *dir_name)
 {
   DIR *dir;
 
@@ -684,8 +681,7 @@ create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
   return (vfs_scan_nok);
 }
 
-gboolean
-check_mounted (CONFIG * my_config)
+gboolean check_mounted (CONFIG * my_config)
 {
   FILE *fp;
   char line[1024];
@@ -770,6 +766,8 @@ start_thread_scan (void *arg)
 		flag_to_umount = TRUE;
 	    }
 	}
+      else
+	flag_to_umount = TRUE;
     }
 
   /* Get the size of the disk to init the progress bar */
