@@ -134,9 +134,9 @@ ok_clicked (GtkWidget * w, gpointer data)
       tmpgn = gns.gn;
       if ((tmpgn) && (tmpgn != gn->parent))
 	{
-	  ERROR_DIALOG
-	    ("A file/dir with the same name already exists in this directory",
-	     edit_window);
+	  ERROR_DIALOG (_("A file/dir with the same name "
+	                  "already exists in this directory"),
+	                edit_window);
 	  return;
 	}
     }
@@ -213,7 +213,7 @@ ok_clicked (GtkWidget * w, gpointer data)
 
     }
   gtk_widget_destroy (edit_window);
-  list_folder (racine->selected_folder->parent);
+  list_folder (racine->selected_folder->parent, TRUE);
   racine->selected_folder = NULL;
   my_config->update_edit_window = FALSE;
   racine->is_modified = TRUE;
@@ -228,7 +228,7 @@ delete_folder (GtkWidget * w, FOLDER * racine)
   suppress_dir (racine->selected_folder);
   description_garbage_collection ();
   gtk_clist_thaw (GTK_CLIST (racine->ctree));
-  list_folder (parent);
+  list_folder (parent, TRUE);
 }
 
 static void
@@ -529,7 +529,7 @@ edit_folder (GtkWidget * w, FOLDER * racine)
 	  gtk_widget_show (recursive_category);
 
 	  recursive_description =
-	    gtk_check_button_new_with_label ("Description");
+	    gtk_check_button_new_with_label (_("Description"));
 	  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
 					(recursive_description), FALSE);
 	  gtk_box_pack_start (GTK_BOX (the_box), recursive_description,
